# If we're using release keys then the path to them will have been via
# BS_RELEASE_KEYS. If it's empty then we're using development
# keys. People who care can inspect this variable to find out whether
# we're doing proper signed releases.
BS_RELEASE_KEYS ?= ""

# Keys only used during development
BS_DEVELOPMENT_KEYS_DIR = "${TOPDIR}/../meta-bs/development-keys"

# The path to the keys we should use for this build.
BS_KEYS_DIR = "${@base_conditional('BS_RELEASE_KEYS', '', '${BS_DEVELOPMENT_KEYS_DIR}', '${BS_RELEASE_KEYS}', d)}"

# The backup public keys are always in the same place. They aren't
# really secret.
BS_BACKUP_KEYS_DIR = "${TOPDIR}/../meta-bs/backup-keys"

# Public keys are always in the same place. They aren't really secret.
BS_PUBLIC_KEYS_DIR = "${TOPDIR}/../meta-bs/public-keys"

# Use cheetah keys for native builds to simplify things
BS_KEYS_MACHINE = "${BASE_MACHINE}"
BS_KEYS_MACHINE_panther-tests = "cheetah"
BS_KEYS_MACHINE_cheetah-tests = "cheetah"
BS_KEYS_MACHINE_panther-x11 = "cheetah"
BS_KEYS_MACHINE_cheetah-x11 = "cheetah"
BS_KEYS_MACHINE_qemux86 = "cheetah"

# It seems that TOPDIR isn't in BB_HASHBASE_WHITELIST so our use of it
# will cause the task hashes to be different in different trees. So,
# we'd better add our directories to the whitelist to avoid this problem.
BB_HASHBASE_WHITELIST_append = " BS_DEVELOPMENT_KEYS_DIR BS_BACKUP_KEYS_DIR BS_PUBLIC_KEYS_DIR"

BS_ROOTFS_PRIVATE_KEY = "${BS_KEYS_DIR}/${BS_KEYS_MACHINE}-rootfs-private.pem"
BS_ROOTFS_PUBLIC_KEY = "${BS_KEYS_DIR}/${BS_KEYS_MACHINE}-rootfs-public.pem"
BS_ROOTFS_PUBLIC_KEY_panther = ""
BS_ROOTFS_PUBLIC_KEY_puma = ""

# By default we don't have a legacy key
BS_KERNEL_LEGACY_PRIVATE_KEY:=""
BS_KERNEL_LEGACY_PUBLIC_KEY:=""

# But Cheetah does have one because early versions of CFE wish the
# kernel to be signed by it.
BS_KERNEL_LEGACY_PRIVATE_KEY_cheetah = "${BS_KEYS_DIR}/${BS_KEYS_MACHINE}-kernel-legacy-private.pem"
BS_KERNEL_LEGACY_PUBLIC_KEY_cheetah = "${BS_KEYS_DIR}/${BS_KEYS_MACHINE}-kernel-legacy-public.pem"

BS_KERNEL_PRIVATE_KEY_panther = ""
BS_KERNEL_PUBLIC_KEY_panther = ""
BS_KERNEL_BACKUP_PUBLIC_KEY_panther = ""

BS_KERNEL_PRIVATE_KEY_puma = ""
BS_KERNEL_PUBLIC_KEY_puma = ""
BS_KERNEL_BACKUP_PUBLIC_KEY_puma = ""

# These keys are generated with commands like:
#    openssl genrsa -out cheetah-kernel-private.pem 2048
#    openssl rsa -in cheetah-kernel-private.pem -pubout -out cheetah-kernel-public.pem
BS_KERNEL_PRIVATE_KEY = "${@base_conditional('BS_RELEASE_KEYS', '', '', '${BS_KEYS_DIR}/${BS_KEYS_MACHINE}-kernel-private.pem', d)}"
BS_KERNEL_PUBLIC_KEY = "${BS_KEYS_DIR}/${BS_KEYS_MACHINE}-kernel-public.pem"
BS_KERNEL_BACKUP_PUBLIC_KEY = "${BS_BACKUP_KEYS_DIR}/${BS_KEYS_MACHINE}-kernel-backup-public.pem"

BS_KERNEL_PRIVATE_KEY_bcm97445 = ""
BS_KERNEL_PUBLIC_KEY_bcm97445 = ""
BS_KERNEL_BACKUP_PUBLIC_KEY_bcm97445 = ""

BSFW_PRIVATE_KEY_panther = ""
BSFW_PUBLIC_KEY_panther = ""
BSFW_BACKUP_PUBLIC_KEY_panther = ""

BSFW_PRIVATE_KEY_puma = ""
BSFW_PUBLIC_KEY_puma = ""
BSFW_BACKUP_PUBLIC_KEY_puma = ""

BSFW_PRIVATE_KEY = "${@base_conditional('BS_RELEASE_KEYS', '', '', '${BS_KEYS_DIR}/${BS_KEYS_MACHINE}-bsfw-private.pem', d)}"
BSFW_PUBLIC_KEY = "${BS_KEYS_DIR}/${BS_KEYS_MACHINE}-bsfw-public.pem"
BSFW_BACKUP_PUBLIC_KEY = "${BS_BACKUP_KEYS_DIR}/${BS_KEYS_MACHINE}-bsfw-backup-public.pem"

BSFW_PRIVATE_KEY_bcm97445 = ""
BSFW_PUBLIC_KEY_bcm97445 = ""
BSFW_BACKUP_PUBLIC_KEY_bcm97445 = ""

BS_BLESSINGS_PRIVATE_KEY_panther = ""
BS_BLESSINGS_PUBLIC_KEY_panther = ""
BS_BLESSINGS_BACKUP_PUBLIC_KEY_panther = ""

BS_BLESSINGS_PRIVATE_KEY_puma = ""
BS_BLESSINGS_PUBLIC_KEY_puma = ""
BS_BLESSINGS_BACKUP_PUBLIC_KEY_puma = ""

BS_BLESSINGS_PRIVATE_KEY = "${@base_conditional('BS_RELEASE_KEYS', '', '', '${BS_KEYS_DIR}/${BS_KEYS_MACHINE}-blessings-private.pem', d)}"
BS_BLESSINGS_PUBLIC_KEY = "${BS_PUBLIC_KEYS_DIR}/${BS_KEYS_MACHINE}-blessings-public.pem"
BS_BLESSINGS_BACKUP_PUBLIC_KEY = "${BS_BACKUP_KEYS_DIR}/${BS_KEYS_MACHINE}-blessings-backup-public.pem"

BS_EXTENSION_PUBLIC_KEY_panther = ""
BS_EXTENSION_PUBLIC_KEY_puma = ""
BS_EXTENSION_PUBLIC_KEY = "${BS_PUBLIC_KEYS_DIR}/${BS_KEYS_MACHINE}-extension-public.pem"

# Cisco has its own SRB-signing key that we only trust for their models
BS_SRB_PUBLIC_KEY = "${BS_PUBLIC_KEYS_DIR}/srb-primary-public.pem"
BS_SRB_BACKUP_PUBLIC_KEY = "${BS_PUBLIC_KEYS_DIR}/srb-backup-public.pem"
BS_SRB_CISCO_PUBLIC_KEY = "${BS_PUBLIC_KEYS_DIR}/srb-cisco-public.pem"
BS_SRB_PUBLIC_KEY_panther-tests = "${BS_DEVELOPMENT_KEYS_DIR}/srb-primary-public.pem"
BS_SRB_BACKUP_PUBLIC_KEY_panther-tests = "${BS_DEVELOPMENT_KEYS_DIR}/srb-backup-public.pem"
