/* crash_kernel.c -- Provide a myriad of ways to crash from kernelspace
 *
 * In order to ensure that we always force a reboot due to various
 * kernel crashes we need to cause those kernel crashes. This module
 * lets us do that.
 *
 * Copyright 2012 BrightSign LLC
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <linux/kernel.h>
#include <linux/module.h>

static uint crash_style;
module_param(crash_style, uint, 0);
MODULE_PARM_DESC(crash_style, "Crash style.");
MODULE_AUTHOR("Mike Crowe <mcrowe@brightsign.biz");
MODULE_DESCRIPTION("Force various types of kernel crash");
MODULE_LICENSE("GPL");

static int unaligned_access(void)
{
	*((volatile u32 *)41) = 42;
	return 0;
}

static int null_pointer(void)
{
	*((volatile u32 *)0) = 42;
	return 0;
}

static int spin_busy(void)
{
	volatile int i;
	while (true)
		++i;

	return 0;
}

static int spin_busy_uninterruptible(void)
{
	volatile int i;
	unsigned long flags;
	local_irq_save(flags);

	while (true)
		++i;

	local_irq_restore(flags);
	return 0;
}

int init_module(void)
{
	printk(KERN_ERR "kernel-crash module loaded for style %u.\n", crash_style);

	switch (crash_style)
	{
	case 0:
		return unaligned_access();
	case 1:
		return null_pointer();
	case 2:
		return spin_busy();
	case 3:
		return spin_busy_uninterruptible();
	case 4:
		panic("Panic called from crash_kernel.c");
		break;
	case 5:
		BUG();
		break;
	default:
		printk("Unrecognised crash style.\n");
		return 0;
	}
}

void cleanup_module(void)
{
	printk("kernel-crash module unloaded.\n");
}
